# Development

Thank you for your interest in contributing to the BDTsim project!

We are currently working on providing documentation on how to extend BDTsim to support more protocols and environments.

For now, please read our [Contribution Guidelines](https://gitlab.com/MatthiasLohr/bdtsim/-/blob/master/CONTRIBUTING.md)
and take a look into the [project issue tracker](https://gitlab.com/MatthiasLohr/bdtsim/-/issues).
